@@ -125,7 +125,7 @@ function ai_helper.print_ts(...)
     local arg = { ... }
     arg[#arg+1] = string.format('[ t = %.3f ]', ts)
 
-    print(table.unpack(arg))
+    std_print(table.unpack(arg))
 
     return ts
 end
@@ -143,7 +143,7 @@ function ai_helper.print_ts_delta(start_time, ...)
     local arg = { ... }
     arg[#arg+1] = string.format('[ t = %.3f, dt = %.3f ]', ts, delta)
 
-    print(table.unpack(arg))
+    std_print(table.unpack(arg))
 
     return ts, delta
 end
@@ -658,17 +658,21 @@ function ai_helper.get_closest_location(hex, location_filter, unit)
     local to_bottom_right = M.distance_between(hex[1], hex[2], width+1, height+1)
     if (to_bottom_right > max_distance) then max_distance = to_bottom_right end
 
+    -- If the hex is supposed to be passable for a unit, it cannot be on the map border
+    local include_borders
+    if unit then include_borders = 'no' end
+
     local radius = 0
     while (radius <= max_distance) do
         local loc_filter = {}
         if (radius == 0) then
             loc_filter = {
-                { "and", { x = hex[1], y = hex[2], radius = radius } },
+                { "and", { x = hex[1], y = hex[2], include_borders = include_borders, radius = radius } },
                 { "and", location_filter }
             }
         else
             loc_filter = {
-                { "and", { x = hex[1], y = hex[2], radius = radius } },
+                { "and", { x = hex[1], y = hex[2], include_borders = include_borders, radius = radius } },
                 { "not", { x = hex[1], y = hex[2], radius = radius - 1 } },
                 { "and", location_filter }
             }
@@ -899,14 +903,27 @@ function ai_helper.get_live_units(filter)
     return wesnoth.get_units { { "not", { status = "petrified" } }, { "and", filter } }
 end
 
-function ai_helper.get_units_with_moves(filter)
+function ai_helper.get_units_with_moves(filter, exclude_guardians)
+    -- Optional input: @exclude_guardians: set to 'true' to exclude units with ai_special=guardian
     -- Note: the order of the filters and the [and] tags are important for speed reasons
-    return wesnoth.get_units { { "and", { formula = "moves > 0" } }, { "and", filter } }
+    local exclude_status = 'petrified'
+    if exclude_guardians then
+        exclude_status = exclude_status .. ',guardian'
+    end
+    return wesnoth.get_units {
+        { "and", { formula = "moves > 0" } },
+        { "not", { status = exclude_status } },
+        { "and", filter }
+    }
 end
 
 function ai_helper.get_units_with_attacks(filter)
     -- Note: the order of the filters and the [and] tags are important for speed reasons
-    return wesnoth.get_units { { "and", { formula = "attacks_left > 0 and size(attacks) > 0" } }, { "and", filter } }
+    return wesnoth.get_units {
+        { "and", { formula = "attacks_left > 0 and size(attacks) > 0" } },
+        { "not", { status = "petrified" } },
+        { "and", filter }
+    }
 end
 
 function ai_helper.get_visible_units(viewing_side, filter)
@@ -1159,7 +1176,7 @@ function ai_helper.get_enemy_dst_src(enemies, cfg)
     end
 
     local cfg_copy = {}
-    if cfg then cfg_copy = ai_helper.table_copy(attack_array) end
+    if cfg then cfg_copy = ai_helper.table_copy(cfg) end
     cfg_copy.moves = 'max'
 
     return ai_helper.get_dst_src_units(enemies, cfg_copy)
