@@ -119,8 +119,8 @@ WESMERE_FOOTER = '''\
 
 <div id="footer"><div id="footer-content"><div>
 	<a href="https://wiki.wesnoth.org/StartingPoints">Site Map</a> &#8226; <a href="https://status.wesnoth.org/">Site Status</a><br />
-	Copyright &copy; 2003&ndash;2018 by <a rel="author" href="https://wiki.wesnoth.org/Project">The Battle for Wesnoth Project</a>.<br />
-	Site design Copyright &copy; 2017&ndash;2018 by Iris Morelle.
+	Copyright &copy; 2003&ndash;2020 by <a rel="author" href="https://wiki.wesnoth.org/Project">The Battle for Wesnoth Project</a>.<br />
+	Site design Copyright &copy; 2017&ndash;2020 by Iris Morelle.
 </div></div></div>
 
 </body></html>
@@ -1301,7 +1301,7 @@ class HTMLOutput:
                 classes_cost.append('rating-' + cost_rating)
             if defense_rating:
                 classes_defense.append('rating-' + defense_rating)
-            if move_cost == '-' or int_fallback(total_movement) <= int_fallback(move_cost, 99):
+            if move_cost == '-' or int_fallback(total_movement) < int_fallback(move_cost, 99):
                 move_cost = HTML_ENTITY_FIGURE_DASH
             else:
                 move_cost = cleantext(move_cost, quote=False)
